/**
 * ----------------------------------------------------------------------------
 * (c) 20012 by Les Retraites Populaires
 * ----------------------------------------------------------------------------
 *
 * RollbackExceptionInterceptor.java
 *
 * PROJECT: FE Migration
 * 
 *
 * $Source$
 * $Revision: 51623 $
 * ----------------------------------------------------------------------------
 * WHEN         WHO     VER     DESCRIPTION
 * 03.05.12     ADL     1.0     Creation
 * ----------------------------------------------------------------------------
 */
package ch.rp.core.shared.ejb.interceptor;

import javax.annotation.Resource;
import javax.ejb.EJBContext;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ch.rp.base.exception.RollBackException;
import ch.rp.services.sharedcontext.SharedContextService;

/**
 * @author adl
 *
 */
public class RollbackExceptionInterceptor {

    private static final Logger LOGGER = LoggerFactory.getLogger(RollbackExceptionInterceptor.class);

    @Resource
    private EJBContext ejbContext;

    @AroundInvoke
    public Object log(InvocationContext ctx) throws Exception {
        try {
            return ctx.proceed();
        } catch (Exception e) {
            perhapsRollbackTransaction(e);
            throw e;
        }
    }

    private void perhapsRollbackTransaction(Throwable exception) {

        if (!(exception instanceof RollBackException)) {
            return;
        }

        /*
		 * Dans le cas d'une exception implémentant l'interface
		 * RollBackException, et si le flag rollbackEnableForRollbackInterceptor
		 * du RP-SharedContext est activé alors la transaction est marquée comme
		 * devant être rollbackée.
		 */
		if (SharedContextService.getInstance().getThreadSharedContext().isRollbackEnableForRollbackInterceptor()) {
			LOGGER.debug("Rollback due to exception {}", exception);
			ejbContext.setRollbackOnly();
		} else {
			LOGGER.debug(
					"RollbackExceptionInterceptor is skipped due to flag rollbackEnableForRollbackInterceptor set to false in RPSharedContext (exception message={})",
					exception.getMessage());
		}
    }

}
