package ch.rp.core.shared.spring;

import org.apache.commons.lang.WordUtils;
import org.springframework.beans.factory.support.AbstractBeanDefinition;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.AbstractBeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.springframework.util.StringUtils;
import org.w3c.dom.Element;

public class RpEjb3BeanDefinitionParser extends AbstractBeanDefinitionParser {

    private static final String JNDI_PREFIX = "jndiCtx";

    private static final String JBOSS_JNDI_NAME_PREFIX = "ejb:";
    
    private static final String JBOSS_JNDI_NAME_LOCAL_PREFIX = "java:global/";
    

    private static final String SEPARATOR = "/";
    

    @Override
    protected AbstractBeanDefinition parseInternal(Element element, ParserContext parserContext) {

        BeanDefinitionBuilder factory = BeanDefinitionBuilder.rootBeanDefinition(LeafCompatibleRemoteEJBProxyFactoryBean.class);

        String alias = element.getAttribute("alias");
        if (StringUtils.hasText(alias)) {
            factory.addPropertyValue("alias", alias);
        }

        String jndiName = element.getAttribute("jndiName");

        String businessInterface = element.getAttribute("businessInterface");
        if (StringUtils.hasText(businessInterface)) {
            factory.addPropertyValue("businessInterface", businessInterface);
            factory.addPropertyValue("homeInterface", businessInterface);
        } else {
            //Use default businessInterface Name
            factory.addPropertyValue("businessInterface", jndiName);
            factory.addPropertyValue("homeInterface", jndiName);
        }

        String lookupHomeOnStartup = element.getAttribute("lookupHomeOnStartup");
        if (StringUtils.hasText(lookupHomeOnStartup)) {
            factory.addPropertyValue("lookupHomeOnStartup", lookupHomeOnStartup);
        } else {
            //Use default lookupHomeOnStartup
            factory.addPropertyValue("lookupHomeOnStartup", false);
        }

        //Building ejb: namespace JNDI Name 
		// ejb:appName/moduleName/distinct-name/ejbName!RemoteInterfaceClassname
		String appName = element.getAttribute("appName");
        String moduleName = element.getAttribute("module");
		String distinctName = "";
        if (!StringUtils.hasText(appName)) {
            //If appName is empty use moduleName as default appName
            appName = moduleName;
        }
        String jndiContextName = JNDI_PREFIX + WordUtils.capitalize(moduleName);
        factory.addPropertyReference("jndiEnvironment", jndiContextName);

        String[] simpleNameTab = jndiName.split("\\.");
        String ejbName = simpleNameTab[simpleNameTab.length - 1];
        
        String local = element.getAttribute("local");
        
		String war = element.getAttribute("war");
		if (StringUtils.hasText(war)) {
			appName = "";
			distinctName = moduleName + SEPARATOR;
		}

        String jbossJndiName;
        if (StringUtils.hasText(local)) {
			jbossJndiName = JBOSS_JNDI_NAME_LOCAL_PREFIX + appName + SEPARATOR + moduleName + SEPARATOR + distinctName
					+ ejbName + "!" + jndiName;
        } else {
			jbossJndiName = JBOSS_JNDI_NAME_PREFIX + appName + SEPARATOR + moduleName + SEPARATOR + distinctName
					+ ejbName + "!" + jndiName;
        }
        
        factory.addPropertyValue("jndiName", jbossJndiName);

        return factory.getBeanDefinition();
    }
}
