package ch.rp.services.sharedcontext;

import java.io.Serializable;

/**
 * Dépôt des variables partagées transmises implicitement entre composants.
 * Une instance de cette classe a une visibilité limitée au thread courant sur
 * le serveur.
 */
public class SharedContextHolder implements Serializable {

    private static final long serialVersionUID = -8636718258275995748L;

    public final static String SHARED_CONTEXT_HOLDER_KEY = "rp-shared-context";

    /** Nom du login utilisateur. */
    private String userName;

    /** application Id utilisé par la Def. Prod. Unique pour
     * définir si l'appel se fait dans un context
     * d'offre ou non.
     */
    private int applicationId = -1;
 
    private String actionId = null;

	/**
	 * Flag permettant de désactiver le roolback du RollbackInterceptor. Si le
	 * flag est à "False" aucun rollback ne sera effectué par l'intercepteur
	 * même si une exception implémentant l'interface RollbackExcpetion est
	 * levée.
	 */
	private boolean rollbackEnableForRollbackInterceptor = true;

    /** Constructeur à portée limitée. */
    SharedContextHolder() {
        //Empty Implementation
}

    /** @return utilisateur */
    public String getUserName() {
        return this.userName;
    }

    /**
     * Définit le nom de login de l'utilisateur.
     * param userName login utilisateur
     */
    public void setUserName(final String userName) {
        this.userName = userName;
    }

    /**
     * @return the application Id
     */
    public int getApplicationId() {
        return this.applicationId;
    }

    /**
     * Setter pour l'application Id
     * @param applicationId
     */
    public void setApplicationId(final int applicationId) {
        this.applicationId = applicationId;
    }

    public String getActionId() {
        return actionId;
    }

    public void setActionId(String actionId) {
        this.actionId = actionId;
    }

	public boolean isRollbackEnableForRollbackInterceptor() {
		return rollbackEnableForRollbackInterceptor;
	}

	public void setRollbackEnableForRollbackInterceptor(boolean rollbackEnableForRollbackInterceptor) {
		this.rollbackEnableForRollbackInterceptor = rollbackEnableForRollbackInterceptor;
	}

}
